
low level API reference
===================================

for full doxygen-generated C-docs, defines and functions please checkout

https://c.delta.chat


Python low-level capi calls
---------------------------


.. automodule:: deltachat.capi.lib
    :members:

